@@ -12,8 +12,8 @@ def requires_ajax(f):
     return wrapper
 
 
-def allowed_methods(methods):
-    """Enforces a list of supplied HTTP methods"""
+def http_methods(*methods):
+    """Enforces one of the supplied HTTP methods"""
     def outer(f):
         @wraps(f)
         def wrapper(request, *args, **kwargs):
@@ -31,3 +31,19 @@ def remove_request(f):
         return f(*args, **kwargs)
     return wrapper
 
+
+def handler_decorators(*decorators):
+    """Converts function decorators into a decorator for ``utkik.BaseView``
+    handlers.
+    """
+    def outer(f):
+        @wraps(f)
+        def wrapper(self, *args, **kwargs):
+            def g(request, *args, **kwargs):
+                return f(self, *args, **kwargs)
+            for d in reversed(decorators):
+                g = d(g)
+            return g(self.request, *args, **kwargs)
+        return wrapper
+    return outer
+
